@@ -12,6 +12,11 @@ preloader={
 						'desc':f'find the volume of height*width*length using pint to normalize the values',
 						'exec':volume_pint
 					},
+	f'{uuid1()}':{
+						'cmds':['cooking units',],
+						'desc':f'review conversions for the kitchen',
+						'exec':CC_Ui
+					},
 	f'{uuid1()}':{
 						'cmds':['self-inductance pint',],
 						'desc':f'find self-inductance using pint to normalize the values for self-inductance=relative_permeability*(((turns**2)*area)/length)*1.26e-6',
