@@ -28,6 +28,7 @@ import decimal
 from decimal import localcontext,Decimal
 unit_registry=pint.UnitRegistry()
 import math
+from radboy.HowDoYouDefineMe.CoreEmotions import *
 
 def volume():
     with localcontext() as ctx:
@@ -1623,7 +1624,7 @@ def ndtp():
             #12 minutes 
             buffer=timedelta(minutes=15)
             original=timedelta(seconds=duration)+timedelta(seconds=breaks)
-            duration=timedelta(seconds=duration+buffer.total_seconds())
+            duration=timedelta(seconds=original.total_seconds()+buffer.total_seconds())
             now=datetime.now()
             then=now+duration
             msg=[]
@@ -1639,4 +1640,4 @@ def ndtp():
             msg='\n\n'.join(msg)
             return msg
         except Exception as e:
-            print(e)
\ No newline at end of file
+            print(e)
